==> haskell-aeson-0.11.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-aeson/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 0.11.1.0
id: aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
key: aeson_1AhuDUMz5ut3n7t9kV1dsC
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser Data.Aeson.Types
    Data.Aeson.TH
hidden-modules: Data.Aeson.Encode.Builder
                Data.Aeson.Encode.Functions Data.Aeson.Functions
                Data.Aeson.Parser.Internal Data.Aeson.Parser.Time
                Data.Aeson.Types.Class Data.Aeson.Types.Generic
                Data.Aeson.Types.Instances Data.Aeson.Types.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.1.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.1.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-0.11.1.0
hs-libraries: HSaeson-0.11.1.0-1AhuDUMz5ut3n7t9kV1dsC
depends:
    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
    fail-4.9.0.0-dd8812a5b6b0a0ce790ee5a93be03a9d
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-0.11.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-aeson/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson
version: 0.11.1.1
id: aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
key: aeson_HkZkS8AGYCk39qlY84xork
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Fast JSON parsing and encoding
description:
    A JSON parsing and encoding library optimized for ease of use
    and high performance.
    .
    To get started, see the documentation for the @Data.Aeson@ module
    below.
    .
    Parsing performance on a late 2013 MacBook Pro (2.6GHz Core i7),
    running 64-bit GHC 7.10.1, for mostly-English tweets from Twitter'\''s
    JSON search API:
    .
    * 6.4 KB payloads, English: 7570 msg\/sec (47.6 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 3261 msg\/sec (46.6 MB\/sec)
    .
    Encoding performance on the same machine and data:
    .
    * 6.4 KB payloads, English: 22738 msg\/sec (142.9 MB\/sec)
    .
    * 14.6 KB payloads, Japanese: 15911 msg\/sec (227.4 MB\/sec)
    .
    (A note on naming: in Greek mythology, Aeson was the father of Jason.)
category: Text, Web, JSON
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Aeson Data.Aeson.Encode Data.Aeson.Internal
    Data.Aeson.Internal.Time Data.Aeson.Parser Data.Aeson.Types
    Data.Aeson.TH
hidden-modules: Data.Aeson.Encode.Builder
                Data.Aeson.Encode.Functions Data.Aeson.Functions
                Data.Aeson.Parser.Internal Data.Aeson.Parser.Time
                Data.Aeson.Types.Class Data.Aeson.Types.Generic
                Data.Aeson.Types.Instances Data.Aeson.Types.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-0.11.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-0.11.1.1
hs-libraries: HSaeson-0.11.1.1-HkZkS8AGYCk39qlY84xork
depends:
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
    fail-4.9.0.0-dd8812a5b6b0a0ce790ee5a93be03a9d
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-aeson/html/aeson.haddock
haddock-html: /usr/share/doc/haskell-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
